/***************************************************************************
                             graphedge.h
                             -------------------
    begin                : Fri Jun 16 2005
    copyright            : (C) 2005 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GRAPHEDGE_H
#define GRAPHEDGE_H

#include <qcanvas.h>
#include "graphviz.h"

/**
 * Draws a directed edge on a canvas.
 * The edge is composed of a spline, which is its body, and a polygon, which
 * is its head.
 * @author Elad Lahav
 */
class GraphEdge : public QCanvasPolygonalItem
{
public:
    GraphEdge(QCanvas*, Agedge_t*);
    ~GraphEdge();

	/**
	 * @return	The graph edge drawn by this item.
	 */
	Agedge_t* getEdge() { return m_pEdge; }
	
	void setPolyPoints(const QPointArray&);
	void setCurvePoints(const QPointArray&);
	
	/**
	 * Returns the area surrounding the edge.
	 * @return	A point array defining the area occupied by this item
	 */
	virtual QPointArray areaPoints() const { return m_arrArea; }
	
	/**
	 * @return	 The bounding rectangle of the edge's head
	 */
	const QRect& boundingRect() { return m_rcBound; }
	
protected:
	virtual void drawShape(QPainter&);
	
private:
	/** The graph edge drawn by this item. */
	Agedge_t* m_pEdge;
	
	/** The points of the polygon part of the edge. */
	QPointArray m_arrPoly;
	
	/** Control points for the spline part of the edge. */
	QPointArray m_arrCurve;
	
	/** Points surrounding the entire edge. */
	QPointArray m_arrArea;
	
	/** The bounding rectangle of the edge's head. */
	QRect m_rcBound;
	
	void calcArea();
};

#endif
